Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2007-04-04 17:18:41 +0400
committerCampbell Barton <ideasman42@gmail.com>2007-04-04 17:18:41 +0400
commitafdd54fa3720c267f30e48ed45c449d80449bac0 (patch)
tree3192044fa53f6e1fd3d1b0256963c2d4c090d700 /source/gameengine/Ketsji/KX_Camera.h
parent203e6ed82b444786d7999e88cebef84d6d429765 (diff)
moved source and text to american spelling
* colour -> color * centre -> center * normalise -> normalize * modelling -> modeling
Diffstat (limited to 'source/gameengine/Ketsji/KX_Camera.h')
-rw-r--r--source/gameengine/Ketsji/KX_Camera.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/source/gameengine/Ketsji/KX_Camera.h b/source/gameengine/Ketsji/KX_Camera.h
index ed926f12123..60f0b107940 100644
--- a/source/gameengine/Ketsji/KX_Camera.h
+++ b/source/gameengine/Ketsji/KX_Camera.h
@@ -83,9 +83,9 @@ protected:
*/
bool m_dirty;
/**
* true if the frustum planes have been normalised.
*/
- bool m_normalised;
+ bool m_normalized;
/**
* View Frustum clip planes.
@@ -104,11 +104,11 @@ protected:
bool m_set_projection_matrix;
/**
* The centre point of the frustum.
*/
- MT_Point3 m_frustum_centre;
+ MT_Point3 m_frustum_center;
MT_Scalar m_frustum_radius;
- bool m_set_frustum_centre;
+ bool m_set_frustum_center;
/**
* Python module doc string.
@@ -120,9 +120,9 @@ protected:
*/
void ExtractClipPlanes();
/**
* Normalise the camera clip frames.
*/
- void NormaliseClipPlanes();
+ void NormalizeClipPlanes();
/**
* Extracts the bound sphere of the view frustum.
*/
@@ -181,11 +181,11 @@ public:
/**
* Tests if the given sphere is inside this camera's view frustum.
*
* @param centre The centre of the sphere, in world coordinates.
* @param radius The radius of the sphere.
* @return INSIDE, INTERSECT, or OUTSIDE depending on the sphere's relation to the frustum.
*/
- int SphereInsideFrustum(const MT_Point3& centre, const MT_Scalar &radius);
+ int SphereInsideFrustum(const MT_Point3& center, const MT_Scalar &radius);
/**
* Tests the given eight corners of a box with the view frustum.
*
@@ -83,9 +83,9 @@ protected:
bool m_dirty;
/**
- * true if the frustum planes have been normalised.
+ * true if the frustum planes have been normalized.
*/
@@ -104,11 +104,11 @@ protected:
bool m_set_projection_matrix;
/**
- * The centre point of the frustum.
+ * The center point of the frustum.
*/
@@ -120,9 +120,9 @@ protected:
void ExtractClipPlanes();
/**
- * Normalise the camera clip frames.
+ * Normalize the camera clip frames.
*/
@@ -181,11 +181,11 @@ public:
* Tests if the given sphere is inside this camera's view frustum.
*
- * @param centre The centre of the sphere, in world coordinates.
+ * @param center The center of the sphere, in world coordinates.
* @param radius The radius of the sphere.
* @return INSIDE, INTERSECT, or OUTSIDE depending on the sphere's relation to the frustum.